import React, { useState, useEffect, useRef } from "react";
import { useTracker } from "meteor/react-meteor-data";
import _ from "lodash";
//import { TextInput, Row } from "react-materialize";

//client side mongo collection, data created publish
const DataTableIds = new Mongo.Collection("DataTablePageIds");

const TableBody = ({
  renderRow,
  headers,
  columns,
  collection,
  subsName,
  filter,
  fulltext,
  sortField,
  sortOrder,
  fields,
  page,
  pageSize,
}) => {
  
  const sort2 = sortField ? { [sortField]: sortOrder } : {};
  const loading = useTracker(() => {
    const subs = [
      Meteor.subscribe(
        subsName,
        filter,
        fulltext,
        sortField,
        sortOrder,
        fields,
        page,
        pageSize
      ),
    ];
    let ready = true;
    subs.forEach((sub) => {
      if (!sub.ready()) ready = false;
    });
    return !ready;
  }, [filter, fulltext, sortField, sortOrder, fields, page, pageSize]);

  const query = useTracker(() => {
    const dti = DataTableIds.findOne({ _id: subsName });
    return { _id: { $in: dti?.ids || [] } };
  }, [filter, fulltext, sortField, sortOrder, fields, page, pageSize, loading]);

  const rows = useTracker(() => {
    if (loading) {
      return [];
    }
    const rowsArray = collection.find(query, { sort: sort2 }).fetch();
    
    return rowsArray;
  }, [filter, fulltext, sortField, sortOrder, fields, page, pageSize, loading]);

  renderRowImpl = (row) => {
    if (renderRow) {
      return renderRow(row);
    }
    const cells = headers
      .filter((h) => h.field === "action" || columns[h.field])
      .map((h, index) => {
        if (h.render && h.render instanceof Function) {
          return h.render(row, h);
        }
        let value = _.get(row, h.field);
        if (h.formatter) {
          if (h.type === "array") {
            value =
              value && Array.isArray(value)
                ? value.map((r) => h.formatter(r)).join(", ")
                : "";
          } else {
            value = h.formatter(value);
          }
        } else {
          switch (h.type) {
            case "array":
              value = value && Array.isArray(value) ? value.join(", ") : "";
              break;

            case "date":
              if (!value) {
                value = "";
                break;
              }
              if (value instanceof Date) {
                const formatDate = h.format || "DD.MM.YYYY";
                value = moment(value).format(formatDate);
              } else {
                value = `${value}`;
              }

              break;

            case "datetime":
              if (!value) {
                value = "";
                break;
              }
              if (value instanceof Date) {
                const formatDateTime = h.format || "DD.MM.YYYY hh:mm";
                value = moment(value).format(formatDateTime);
              } else {
                value = `${value}`;
              }
              break;

            case "boolean":
              value = value ? (
                <i
                  className={"fa fa-check green-text text-darken-3"}
                  aria-hidden={true}
                ></i>
              ) : (
                <i
                  className={"fa fa-times red-text text-darken-2"}
                  aria-hidden={true}
                ></i>
              );
              break;
          }
        }
        value = value || "";
        if (h.onClick) {
          value = (
            <a
              href="#"
              onClick={(event) => {
                event.preventDefault();
                h.onClick(row);
              }}
            >
              {value}
            </a>
          );
        }
        const cls = "dt-cell-" + (h.type || "string");
        return (
          <td key={h.field + index} className={cls}>
            {value}
          </td>
        );
      });

    return <tr key={row._id}>{cells}</tr>;
  };
  return <tbody>{rows.map((row) => renderRowImpl(row))}</tbody>;
};

export default TableBody;
