import React, { useState, useEffect, useRef } from "react";
import { useTracker } from "meteor/react-meteor-data";
import _ from "lodash";
import { i18n } from "meteor/universe:i18n";
import { Pagination, Row, Col } from "react-materialize";

//counter is client side collection, data created publish counter
const Counter = new Mongo.Collection("DataTableCounter");

const TablePaginator = ({
  subsName,
  filter,
  updateInitalData,
  sort,
  fulltext,
  page,setPage,
  pageSize,
  columns,
}) => {
  const T = i18n.createComponent();

  const loading = useTracker(() => {
    const sub = Meteor.subscribe(subsName + "Count", filter, fulltext);
    return !sub.ready();
  }, [page, pageSize, filter, fulltext]);

  const totalItems = useTracker(() => {
    const c = Counter.findOne({ _id: subsName });
    return c ? c.count : 0;
  }, [page, pageSize, filter, loading]);

  return (
    <Row style={{ width: "calc(100% - 20px)" }}>
      <Col s={12} m={8}>
        {!loading && totalItems > pageSize && (
          <Pagination
            className={"center"}
            activePage={page + 1}
            items={Math.ceil(totalItems / pageSize)}
            leftBtn={<i className="fa fa-chevron-left"></i>}
            maxButtons={8}
            rightBtn={<i className="fa fa-chevron-right"></i>}
            onSelect={(p) => {
              if (setPage) {
                setPage(p - 1);
              }
              updateInitalData(p - 1, sort, fulltext, pageSize, columns);
            }}
          />
        )}
      </Col>
      <Col s={12} m={4} style={{ textAlign: "right" }}>
        {loading ? 'loading....' : ''}
        {!loading && <div className="right"><T>messages.records_count</T>: {totalItems}</div>}
      </Col>
    </Row>
  );
};

export default TablePaginator;
